;
;
;  IR Link Library v1.0 for the TI89 and TI92+
;
;      by Sami Khawam ( sKhawam@bigfoot.com )
;
;
;  This library will enable you to use the IR Link. There are only
;  4 routines now, but new routines will be added in the future ( like
;  remote control encoding, decoding...).
;
;  Although the ROM link routines can be used with the IR Link, this
;  library has it own linking routines ( work also without the IR Link ).
;
;  This library is accualy an executable asm program. When executed
;  the user will be able to change the settings of the library.
;  Currently there are 3 settings you can change:
;
;  -Swap Lines: On/Off .
;   This option is useful if you have unintetionaly swaped the red
;   and the white wires of the calc-ir_link connection. Use it
;   if you dont want to solder the cable again.
;
;  -Timeout duration:
;   Set the duration that the calc should try to transfer data
;   when it doesn't receive anything.
;
;  -Linking Delay:
;   Set the linking delay. Maybe useful if connected with a
;   slower calc(eg. TI82), or if you are getting errors.
;
;  If you haven't yet heard of the IR Link, take a look at my homepage:
; 
;      http://sami.ticalc.org
;
;
;  Thanks for Antoine Mercier for having ported
;  the PutByte routine from the TI85.
;
;
;  Sami Khawam


;*****************************************************
; PutByte:  Send a byte to the IR Link
; Input:    d3.b  Byte to send
; Output:   none
; Destroyed: d4
;
; Thanks for Antoine Mercier for having ported
; this routine from the TI85.

irlib::PutByte    equ   irlib@0000


;*****************************************************
; PutLink:  Send a byte/word of longword to the IR Link
; Input:    d3  data to send
;           d4  number of bits -1 (7...31)
; Output:   none
; Destroyed: none
;
; Thanks for Antoine Mercier for having ported
; this routine from the TI85.

irlib::PutLink    equ   irlib@0001


;*****************************************************
; GetByte:  Get a byte from the IR Link
; Input:    none
; Output:   d3.b  Byte received
; Destroyed: d4

irlib::GetByte    equ   irlib@0002


;*****************************************************
; PutLink:  Get a byte/word of longword from the IR Link-DOESN'T WORK
; Input:    d4.w  Number of Bits
; Output:   d3    data received
; Destroyed: none
;
; The GetLink routine DOES NOT WORK!

irlib::GetLink    equ   irlib@0003


;*****************************************************
; Convert between frequency in KHz to delay units needed by the IR Link.
; Input:    d2.b  Freq in KHz.
; Output:   d3.w  contains the 2 delay values.
; Used:     a2

irlib::Freq2Delay equ   irlib@0004

